package org.eco.als.domain.bo;

import com.fasterxml.jackson.annotation.JsonFormat;
import io.github.linpeilie.annotations.AutoMapper;
import jakarta.validation.constraints.NotBlank;
import jakarta.validation.constraints.NotNull;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.eco.als.domain.FlightTask;
import org.eco.common.orm.core.domain.BaseEntity;

import java.util.Date;

/**
 * 飞行任务业务对象 als_flight_task_t
 *
 * @author wgk
 * @date 2024-07-24
 */
@Data
@EqualsAndHashCode(callSuper = true)
@AutoMapper(target = FlightTask.class, reverseConvertGenerate = false)
public class FlightTaskBo extends BaseEntity {
    /**
     * 编号
     */
    @NotNull(message = "编号不能为空")
    private Long id;

    /**
     * 架次号
     */
    @NotNull(message = "架次号不能为空")
    private Long sortieNo;

    /**
     * 机型
     */
    @NotBlank(message = "机型不能为空")
    private String aircraftModel;

    /**
     * 机号Id
     */
    @NotNull(message = "机号不能为空")
    private String aircraftId;

    /**
     * 起飞时间
     */
    @NotNull(message = "起飞时间不能为空")
    @JsonFormat(pattern = "yyyy-MM-dd")
    private Date startTime;

    /**
     * 降落时间
     */
    @NotBlank(message = "降落时间不能为空")
    private String endTime;

    /**
     * 飞行课目
     */
    @NotBlank(message = "飞行课目不能为空")
    private String trainExercise;

    /**
     * 状态
     */
    private String status;


}
