package org.eco.als.domain.vo;

import com.alibaba.excel.annotation.ExcelIgnoreUnannotated;
import com.alibaba.excel.annotation.ExcelProperty;
import com.eco.common.mapper.annotation.FieldMapper;
import com.eco.common.mapper.constant.MapperConstant;
import com.mybatisflex.annotation.Id;
import io.github.linpeilie.annotations.AutoMapper;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.eco.als.domain.DataImport;
import org.eco.common.excel.annotation.ExcelDictFormat;
import org.eco.common.excel.convert.ExcelDictConvert;
import org.eco.common.orm.core.domain.BaseEntity;

import java.io.Serial;
import java.io.Serializable;
import java.util.Date;

/**
 * 数据导入信息视图对象 als_data_import_t
 *
 * @author wgk
 * @date 2024-07-22
 */
@Data
@ExcelIgnoreUnannotated
@EqualsAndHashCode(callSuper = true)
@AutoMapper(target = DataImport.class)
public class DataImportVo extends BaseEntity implements Serializable {

    @Serial
    private static final long serialVersionUID = 1L;

    /**
     * 唯一编号
     */
    @Id
    private Long id;

    /**
     * 文件编号
     */
    @ExcelProperty(value = "文件编号")
    private Long ossId;

    /**
     * 机号Id
     */
    private String aircraftId;

    /**
     * 数据源
     */
    @ExcelProperty(value = "数据源", converter = ExcelDictConvert.class)
    @ExcelDictFormat(dictType = "common_type")
    private String source;

    /**
     * 架次号
     */
    @ExcelProperty(value = "架次号")
    private String sortieNo;

    /**
     * 机号
     */
    @ExcelProperty(value = "机号")
    @FieldMapper(type = MapperConstant.AIRCRAFT_ID_TO_NO, mapper = "aircraftId")
    private String aircraftNo;

    /**
     * 飞行日期
     */
    @ExcelProperty(value = "飞行日期")
    private Date flightDate;

    /**
     * 状态（1正常）
     */
    @ExcelProperty(value = "状态", converter = ExcelDictConvert.class)
    @ExcelDictFormat(dictType = "common_type")
    private String status;

    /**
     * 删除标识（1删除 0未删除）
     */
    private Integer delFlag;


    /**
     * 创建人名称
     */
    @FieldMapper(type = MapperConstant.USER_ID_TO_NAME, mapper = "createBy")
    private String createByName;

    /**
     * 创建人名称
     */
    @FieldMapper(type = MapperConstant.USER_ID_TO_NAME, mapper = "updateBy")
    private String updateByName;

}
