package org.eco.als.listener;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.ObjectUtil;
import com.alibaba.excel.context.AnalysisContext;
import com.alibaba.excel.event.AnalysisEventListener;
import lombok.extern.slf4j.Slf4j;
import org.eco.als.domain.bo.SafeRuleBo;
import org.eco.als.domain.vo.SafeRuleImportVo;
import org.eco.als.domain.vo.SafeRuleVo;
import org.eco.als.service.ISafeRuleService;
import org.eco.common.core.core.domain.model.LoginUser;
import org.eco.common.core.utils.SpringUtils;
import org.eco.common.core.utils.ValidatorUtils;
import org.eco.common.excel.core.ExcelListener;
import org.eco.common.excel.core.ExcelResult;
import org.eco.common.excel.entity.ExcelResultRes;

import java.util.List;

/**
 * 保障规则自定义导入
 *
 * @author wgk
 */
@Slf4j
public class SafeRuleImportListener extends AnalysisEventListener<SafeRuleImportVo> implements ExcelListener<SafeRuleImportVo> {
    private final ISafeRuleService safeRuleService;

    private final Boolean isUpdateSupport;
    private final LoginUser loginUser;
    private final StringBuilder successMsg = new StringBuilder();
    private final StringBuilder failureMsg = new StringBuilder();
    private int successNum = 0;
    private int failureNum = 0;

    public SafeRuleImportListener(Boolean isUpdateSupport, LoginUser loginUser) {
        this.safeRuleService = SpringUtils.getBean(ISafeRuleService.class);
        this.isUpdateSupport = isUpdateSupport;
        this.loginUser = loginUser;
    }

    @Override
    public void invoke(SafeRuleImportVo safeRuleVo, AnalysisContext context) {
        try {

            SafeRuleBo safeRuleBo = BeanUtil.toBean(safeRuleVo, SafeRuleBo.class);

            //TODO:根据某个字段，查询数据库表中是否存在记录，不存在就新增，存在就更新
            SafeRuleVo safeRuleVo1 = null;

            //safeRuleVo1 = safeRuleService.selectBySomefield(safeRuleVo.getSomefield());
            if (ObjectUtil.isNull(safeRuleVo1)) {
                //不存在就新增
                setBo(safeRuleBo);
                ValidatorUtils.validate(safeRuleBo);
                boolean inserted = safeRuleService.insert(safeRuleBo);

                if (inserted) {
                    successNum++;
                    successMsg.append("<br/>").append(successNum).append("、保障规则 记录导入成功");
                } else {
                    failureNum++;
                    failureMsg.append("<br/>").append(failureNum).append("、保障规则 记录导入失败");
                }
            } else if (isUpdateSupport) {
                //存在就更新
                safeRuleBo.setId(safeRuleVo1.getId());//主键
                safeRuleBo.setVersion(safeRuleVo1.getVersion());
                boolean updated = safeRuleService.update(safeRuleBo);
                if (updated) {
                    successNum++;
                    successMsg.append("<br/>").append(successNum).append("、保障规则 记录更新成功");
                } else {
                    failureNum++;
                    failureMsg.append("<br/>").append(failureNum).append("、保障规则 记录更新失败");
                }
            }
        } catch (Exception e) {
            failureNum++;
            String msg = "<br/>" + failureNum + "、保障规则 记录导入失败：";
            failureMsg.append(msg).append(e.getMessage());
            log.error(msg, e);
        }
    }

    private void setBo(SafeRuleBo safeRuleBo) {
        safeRuleBo.setVersion(0);
        safeRuleBo.setCreateBy(loginUser.getUserId());
        safeRuleBo.setUpdateBy(loginUser.getUserId());
        safeRuleBo.setTenantId(loginUser.getTenantId());
    }

    @Override
    public void doAfterAllAnalysed(AnalysisContext context) {
        log.info("解析完成");
    }

    @Override
    public ExcelResult<SafeRuleImportVo> getExcelResult() {
        return new ExcelResult<>() {

            @Override
            public ExcelResultRes getAnalysis() {
                if (failureNum > 0 && successNum == 0) {
                    failureMsg.insert(0, "很抱歉，导入失败！共 " + failureNum + " 条数据没有成功导入，错误如下：");
                    return ExcelResultRes.builder().logInfo(failureMsg.toString()).status("0").build();
                } else if (failureNum > 0 && successNum > 0) {
                    failureMsg.insert(0, "很抱歉，部分导入失败！共 " + failureNum + " 条数据没有成功导入，错误如下：");
                    return ExcelResultRes.builder().logInfo(failureMsg.toString()).status("2").build();
                } else {
                    successMsg.insert(0, "恭喜您，数据已全部导入成功！共 " + successNum + " 条，数据如下：");
                    return ExcelResultRes.builder().logInfo(successMsg.toString()).status("1").build();
                }
            }

            @Override
            public List<SafeRuleImportVo> getList() {
                return null;
            }

            @Override
            public List<String> getErrorList() {
                return null;
            }
        };
    }
}
