package org.eco.als.service;

import org.eco.als.domain.LifePredictionResult;
import org.eco.als.domain.bo.LifePredictionResultBo;
import org.eco.als.domain.vo.LifePredictionResultVo;
import org.eco.common.core.core.domain.model.LoginUser;
import org.eco.common.core.core.page.PageResult;
import org.eco.common.orm.core.service.IBaseService;
import org.springframework.scheduling.annotation.Async;

import java.util.List;

/**
 * 寿命预测结果Service接口
 *
 * @author wgk
 * @date 2024-07-26
 */
public interface ILifePredictionResultService extends IBaseService<LifePredictionResult> {
    /**
     * 查询寿命预测结果
     *
     * @param id 寿命预测结果主键
     * @return 寿命预测结果
     */
    LifePredictionResultVo selectById(Long id);

    /**
     * 查询寿命预测结果列表
     *
     * @param lifePredictionResultBo 寿命预测结果Bo
     * @return 寿命预测结果集合
     */
    List<LifePredictionResultVo> selectList(LifePredictionResultBo lifePredictionResultBo);

    /**
     * 分页查询寿命预测结果列表
     *
     * @param lifePredictionResultBo 寿命预测结果Bo
     * @return 分页寿命预测结果集合
     */
    PageResult<LifePredictionResultVo> selectPage(LifePredictionResultBo lifePredictionResultBo);

    /**
     * 新增寿命预测结果
     *
     * @param lifePredictionResultBo 寿命预测结果Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insert(LifePredictionResultBo lifePredictionResultBo);

    /**
     * 新增寿命预测结果，前台提供主键值，一般用于导入的场合
     *
     * @param lifePredictionResultBo 寿命预测结果Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insertWithPk(LifePredictionResultBo lifePredictionResultBo);

    /**
     * 修改寿命预测结果
     *
     * @param lifePredictionResultBo 寿命预测结果Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    boolean update(LifePredictionResultBo lifePredictionResultBo);

    /**
     * 批量删除寿命预测结果
     *
     * @param ids 需要删除的寿命预测结果主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    boolean deleteByIds(Long[] ids);

    /**
     * asyncExport 异步导出
     *
     * @param listVo    数据列表
     * @param sheetName 文件名称
     * @param user      上下文
     */
    @Async
    void asyncExport(List<LifePredictionResultVo> listVo, String sheetName, LoginUser user);

}
