package org.eco.als.service;

import org.eco.als.domain.TechnicalDoc;
import org.eco.als.domain.bo.TechnicalDocBo;
import org.eco.als.domain.vo.TechnicalDocVo;
import org.eco.common.core.core.domain.model.LoginUser;
import org.eco.common.core.core.page.PageResult;
import org.eco.common.orm.core.service.IBaseService;
import org.springframework.scheduling.annotation.Async;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;

/**
 * 技术资料Service接口
 *
 * @author wgk
 * @date 2024-07-18
 */
public interface ITechnicalDocService extends IBaseService<TechnicalDoc> {
    /**
     * 查询技术资料
     *
     * @param id 技术资料主键
     * @return 技术资料
     */
    TechnicalDocVo selectById(Long id);

    /**
     * 查询技术资料列表
     *
     * @param technicalDocBo 技术资料Bo
     * @return 技术资料集合
     */
    List<TechnicalDocVo> selectList(TechnicalDocBo technicalDocBo);

    /**
     * 分页查询技术资料列表
     *
     * @param technicalDocBo 技术资料Bo
     * @return 分页技术资料集合
     */
    PageResult<TechnicalDocVo> selectPage(TechnicalDocBo technicalDocBo);

    /**
     * 新增技术资料
     *
     * @param technicalDocBo 技术资料Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insert(TechnicalDocBo technicalDocBo);

    /**
     * 新增技术资料，前台提供主键值，一般用于导入的场合
     *
     * @param technicalDocBo 技术资料Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insertWithPk(TechnicalDocBo technicalDocBo);

    /**
     * 修改技术资料
     *
     * @param technicalDocBo 技术资料Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    boolean update(TechnicalDocBo technicalDocBo);

    /**
     * 批量删除技术资料
     *
     * @param ids 需要删除的技术资料主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    boolean deleteByIds(Long[] ids);

    /**
     * 异步导入
     *
     * @param file          导入的文件
     * @param updateSupport 是否覆盖
     * @param user          用户上下文信息
     */
    @Async
    void asyncImportData(MultipartFile file, boolean updateSupport, LoginUser user);

    /**
     * asyncExport 异步导出
     *
     * @param listVo    数据列表
     * @param sheetName 文件名称
     * @param user      上下文
     */
    @Async
    void asyncExport(List<TechnicalDocVo> listVo, String sheetName, LoginUser user);

}
